Crate upack

Crate upack 

Modules

uint16
16-bit integer bitpacking routines
uint32
32-bit integer bitpacking routines

Structs

CompressionDetails
Information about the compressed block.

Constants

X128
128 elements

Traits

CompressibleArray
An array of values that can be compressed.

Functions

compress
Apply bitpacking compression to the provided input.
compress_delta
Apply bitpacking compression to the provided input after first applying Delta encoding to the array.
compress_delta1
Apply bitpacking compression to the provided input after first applying Delta-1 encoding to the array.
decompress
Decompress the input block containing the packed values, writing the decompressed values to out.
decompress_delta
Decompress the input block containing the packed values, reverse the Delta encoding and then writing the decompressed values to out.
decompress_delta1
Decompress the input block containing the packed values, reverse the Delta-1 encoding and then writing the decompressed values to out.